@@ -37,7 +37,7 @@ forecast.ftsm <- function (object, h = 10, method = c("ets", "arima", "ar", "ets
     usedata <- min(usedata, l)
     ytsp <- tsp(object$coeff)
     x <- xx <- ts(as.matrix(object$coeff[(l - usedata + 1):l, 
-        ]), s = ytsp[1] + l - usedata, f = ytsp[3])
+        ]), start = ytsp[1] + l - usedata, frequency = ytsp[3])
     xx[object$weights[(l - usedata + 1):l] < 0.1, ] <- NA
     fmodels <- list()
     if (method == "ets") {
@@ -169,14 +169,14 @@ forecast.ftsm <- function (object, h = 10, method = c("ets", "arima", "ar", "ets
     }
     else stop("Unknown method")
     ytsp <- tsp(object$fitted$time)
-    error <- ts(object$coeff - fitted, s = ytsp[1], f = ytsp[3])
+    error <- ts(object$coeff - fitted, start = ytsp[1], frequency = ytsp[3])
     ferror <- onestepfcast <- object$y
     onestepfcast$y <- object$basis %*% t(fitted)
     onestepfcast$yname <- "One step forecasts"
     ferror$y <- object$y$y - onestepfcast$y
     ferror$yname <- "One step errors"
-    fmean <- fts(object$y$x, object$basis %*% t(meanfcast), s = ytsp[2] + 
-        1, f = ytsp[3], xname = object$y$xname, yname = "Forecasts")
+    fmean <- fts(object$y$x, object$basis %*% t(meanfcast), start = ytsp[2] + 
+        1, frequency = ytsp[3], xname = object$y$xname, yname = "Forecasts")
     res <- object$residuals
     res$y <- res$y^2
     vx <- rowMeans(res$y)
@@ -192,18 +192,18 @@ forecast.ftsm <- function (object, h = 10, method = c("ets", "arima", "ar", "ets
         stop("Multiple confidence levels not yet implemented")
     if (pimethod == "parametric") {
         tmp <- qconf * sqrt(totalvar)
-        flower <- fts(object$y$x, fmean$y - tmp, s = ytsp[2] + 
-            1, f = ytsp[3], xname = object$y$xname, yname = "Forecast lower limit")
-        fupper <- fts(object$y$x, fmean$y + tmp, s = ytsp[2] + 
-            1, f = ytsp[3], xname = object$y$xname, yname = "Forecast upper limit")
+        flower <- fts(object$y$x, fmean$y - tmp, start = ytsp[2] + 
+            1, frequency = ytsp[3], xname = object$y$xname, yname = "Forecast lower limit")
+        fupper <- fts(object$y$x, fmean$y + tmp, start = ytsp[2] + 
+            1, frequency = ytsp[3], xname = object$y$xname, yname = "Forecast upper limit")
         coeff <- list()
         for (i in 1:nb) {
             coeff[[i]] <- structure(list(mean = ts(meanfcast[, 
-                i], s = ytsp[2] + 1, f = ytsp[3]), lower = ts(meanfcast[, 
-                i] - qconf * sqrt(varfcast[, i]), s = ytsp[2] + 
-                1, f = ytsp[3]), upper = ts(meanfcast[, i] + 
-                qconf * sqrt(varfcast[, i]), s = ytsp[2] + 1, 
-                f = ytsp[3]), level = level, x = x[, i], method = method, 
+                i], start = ytsp[2] + 1, frequency = ytsp[3]), lower = ts(meanfcast[, 
+                i] - qconf * sqrt(varfcast[, i]), start = ytsp[2] + 
+                1, frequency = ytsp[3]), upper = ts(meanfcast[, i] + 
+                qconf * sqrt(varfcast[, i]), start = ytsp[2] + 1, 
+                frequency = ytsp[3]), level = level, x = x[, i], method = method, 
                 model = fmodels[[i]]), class = "forecast")
         }
         names(coeff) <- paste("Basis", 1:nb)
@@ -216,9 +216,9 @@ forecast.ftsm <- function (object, h = 10, method = c("ets", "arima", "ar", "ets
     }
     else {
         junk = ftsmPI(object, B = B, level = level, h = h, fmethod = "ets")
-        lb = fts(object$y$x, junk$lb, s = ytsp[2] + 1, f = ytsp[3], 
+        lb = fts(object$y$x, junk$lb, start = ytsp[2] + 1, frequency = ytsp[3], 
             xname = object$y$xname, yname = "Forecast lower limit")
-        ub = fts(object$y$x, junk$ub, s = ytsp[2] + 1, f = ytsp[3], 
+        ub = fts(object$y$x, junk$ub, start = ytsp[2] + 1, frequency = ytsp[3], 
             xname = object$y$xname, yname = "Forecast upper limit")
         return(structure(list(mean = fmean, bootsamp = junk$bootsamp, 
             lower = lb, upper = ub, model = object), class = "ftsf"))
